[−][src]Enum git_checks::checks::ChangelogStyle
The style of changelog management in use.
Variants
DirectoryA directory stores a file per changelog entry.
Fields of Directory
FileA file contains the changelog entries for a project.
Fields of File
path: StringThe path to the changelog.
Methods
impl ChangelogStyle[src]
pub fn file<P>(path: P) -> Self where
P: ToString, [src]
P: ToString,
A changelog stored in a file at a given path.
pub fn directory<P>(path: P, ext: Option<String>) -> Self where
P: ToString, [src]
P: ToString,
A directory containing many files, each with a changelog entry.
Entries may also be required to have a given extension.