[−][src]Enum git_checks::checks::ValidNameFullNamePolicy
Configuration value for ValidName policy for use of full names in identities.
Variants
RequiredA full name is required, error when missing.
PreferredA full name is preferred, warning when missing.
OptionalA full name is optional, no diagnostic when missing.