[−][src]Struct git_checks::checks::ReleaseBranch
A check which checks for release branch eligibility.
Methods
impl ReleaseBranch[src]
impl ReleaseBranchpub fn new<B, C>(branch: B, commit: C) -> Self where | [src] |
Create a check which checks that a branch is eligible for a release branch.
By default, it only messages that a branch is eligible.
pub fn set_required(&mut self, required: bool) -> &mut Self | [src] |
Set whether the eligibility is required.
Use this for release branches to check that they do not bring in unwanted history.