pub struct ThirdParty {
    pub name: String,
    pub path: String,
    pub root: String,
    pub utility: String,
}
Description of a third party package imported using Kitware’s third party import process.

The workflow used at Kitware for third party packages is to keep all changes tracked in separate repositories. This makes tracking patches to the projects easier to manage and extract for submission to the appropriate upstream project.

When a project is imported, it uses a separate history which contains only snapshots of the tracked repository. When imported into a project, it can select a subset of files to keep, drop extra metadata into the import, or perform other transformations as necessary. Whatever the result of that is, it is added as a new commit on the history of the tracking branch for the project. This is then merged into the main project using a subtree strategy to move the project to the correct place.

This check checks to make sure that any modifications in the main project’s imported location of the third party project are made on the tracking branch.

Fields

name: String

The name of the imported project.

path: String

The path the third party project lives once merged.

root: String

The root commit of the third party tracking branch.

utility: String

The location of the utility to use for importing this project.

Implementations

Create a new third party import configuration.